Method: BitBucket::Repos#create
- Defined in:
- lib/bitbucket_rest_api/repos.rb
#create(*args) ⇒ Object
FIXME: ‘POST a new repository’ is a deprecated feature of the API Create a new repository for the authenticated user.
Parameters
<tt>:name</tt> - Required string
<tt>:description</tt> - Optional string
<tt>:website</tt> - Optional string
<tt>:is_private</tt> - Optional boolean - <tt>true</tt> to create a private repository, <tt>false</tt> to create a public one.
<tt>:has_issues</tt> - Optional boolean - <tt>true</tt> to enable issues for this repository, <tt>false</tt> to disable them
<tt>:has_wiki</tt> - Optional boolean - <tt>true</tt> to enable the wiki for this repository, <tt>false</tt> to disable it. Default is <tt>true</tt>
<tt>:owner</tt> Optional string - The team in which this repository will be created
Examples
bitbucket = BitBucket.new
bitbucket.repos.create "name" => 'repo-name'
"description": "This is your first repo",
"website": "https://bitbucket.com",
"is_private": false,
"has_issues": true,
"has_wiki": true
Create a new repository in this team. The authenticated user must be a member of this team
Examples:
bitbucket = BitBucket.new :oauth_token => '...', :oauth_secret => '...'
bitbucket.repos.create :name => 'repo-name', :owner => 'team-name'
154 155 156 157 158 159 160 161 162 |
# File 'lib/bitbucket_rest_api/repos.rb', line 154 def create(*args) params = args. normalize! params filter! VALID_REPO_OPTIONS + %w[ org ], params assert_required_keys(%w[ name ], params) # Requires authenticated user post_request("/1.0/repositories/", DEFAULT_REPO_OPTIONS.merge(params)) end |